join

Function join 

pub fn join<A, B, RA, RB>(a: A, b: B) -> (RA, RB)
where A: FnOnce(&Worker) -> RA + Send, B: FnOnce(&Worker) -> RB + Send, RA: Send, RB: Send,
Executes two closures on the current thread pool and returns the results.

If there is no current thread pool, this panics.

See also: Worker::join and ThreadPool::join.