pub fn join<A, B, RA, RB>(a: A, b: B) -> (RA, RB)Expand description
Executes two closures on the current thread pool and returns the results.
If there is no current thread pool, this panics.
See also: Worker::join and ThreadPool::join.
pub fn join<A, B, RA, RB>(a: A, b: B) -> (RA, RB)Executes two closures on the current thread pool and returns the results.
If there is no current thread pool, this panics.
See also: Worker::join and ThreadPool::join.